/// <reference types="react" />
import { Context, IViewContext } from './context/view-context';
import { IWorkspace } from './workspace';
import { IResource } from './resource';
import { IPublicModelWindow, IPublicTypeDisposable } from '@alilc/lowcode-types';
interface IWindowCOnfig {
    title: string | undefined;
    options?: Object;
    viewType?: string | undefined;
    sleep?: boolean;
}
export interface IEditorWindow extends Omit<IPublicModelWindow<IResource>, 'changeViewType' | 'currentEditorView' | 'editorViews'> {
    readonly resource: IResource;
    editorViews: Map<string, IViewContext>;
    editorView: IViewContext;
    changeViewType: (name: string, ignoreEmit?: boolean) => void;
    initReady: boolean;
    sleep?: boolean;
    init(): void;
    updateState(state: WINDOW_STATE): void;
}
export declare enum WINDOW_STATE {
    sleep = "sleep",
    active = "active",
    inactive = "inactive",
    destroyed = "destroyed"
}
export declare class EditorWindow implements IEditorWindow {
    readonly resource: IResource;
    readonly workspace: IWorkspace;
    private config;
    id: string;
    icon: React.ReactElement | undefined;
    private emitter;
    title: string | undefined;
    url: string | undefined;
    editorView: Context;
    editorViews: Map<string, Context>;
    initReady: boolean;
    sleep: boolean | undefined;
    constructor(resource: IResource, workspace: IWorkspace, config: IWindowCOnfig);
    updateState(state: WINDOW_STATE): void;
    importSchema(schema: any): Promise<void>;
    save(): Promise<any>;
    onSave(fn: () => void): () => void;
    init(): Promise<void>;
    initViewTypes: () => Promise<void>;
    onChangeViewType(fn: (viewName: string) => void): IPublicTypeDisposable;
    execViewTypesInit: () => Promise<void>;
    setDefaultViewType: () => void;
    get resourceType(): "webview" | "editor";
    initViewType: (name: string) => Promise<void>;
    changeViewType: (name: string, ignoreEmit?: boolean) => void;
    get project(): import("@alilc/lowcode-types").IPublicApiProject;
    get innerProject(): import("@alilc/lowcode-designer").IProject;
    get innerSkeleton(): import("@alilc/lowcode-editor-skeleton").Skeleton;
    get innerSetters(): import("@alilc/lowcode-editor-core").Setters;
    get innerHotkey(): import("@alilc/lowcode-editor-core").IHotKey;
    get editor(): import("@alilc/lowcode-editor-core").Editor;
    get designer(): import("@alilc/lowcode-designer").IDesigner;
    get plugins(): import("@alilc/lowcode-types").IPublicApiPlugins;
    get innerPlugins(): import("@alilc/lowcode-designer").ILowCodePluginManager;
}
export {};
